Learn R Programming

nor1mix (version 1.0-7)

dnorMix: Normal Mixture Density

Description

Evaluate the density function of the normal mixture specified as norMix object.

Usage

dnorMix (x, obj,        log = FALSE)
dnorMixL(obj, x = NULL, log = FALSE, xlim = NULL, n = 511)

Arguments

obj
an object of class norMix.
x
numeric vector with abscissa values where to evaluate the density. For dnorMixL() by default, when NULL, it is constructed from n (and xlim if that is specified).
log
logical indicating log-density values should be returned.
xlim
range of abscissa values, used if x == NULL. By default, xlim is taken as mean plus/minus 3 standard deviations of the normal mixture.
n
number of abscissa values to generate if x is not specified.

Value

  • dnorMix(x) returns the numeric vector of density values $f(x)$, logged if log is TRUE.

    dnorMixL() returns a list with components

  • xthe abscissa values.
  • ythe density values $f(x)$ as for dnorMix().

See Also

rnorMix for random number generation, and norMix for the construction and further methods, particularly plot.norMix which makes use dnorMix.

Examples

Run this code
ff <- dnorMixL(MW.nm7)
 str(ff)
 plot(ff, type = "h") # rather use plot(ff, ...)

Run the code above in your browser using DataLab